#
# spec file for package cabal2spec
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cabal2spec
%bcond_with tests
Name:           %{pkg_name}
Version:        2.6.2
Release:        bp155.3.14
Summary:        Convert Cabal files into rpm spec files
License:        GPL-3.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
%endif

%description
Convert Cabal files into a
<http://ftp.rpm.org/max-rpm/s1-rpm-build-creating-spec-file.html spec file>
suitable for building the package with the RPM package manager. This tool
primarily targets the <http://www.suse.com/ SUSE> and <http://www.opensuse.org
openSUSE> familiy of distributions. Support for other RPM-based distributions
is currently not available. Check out
<http://hackage.haskell.org/package/cabal-rpm cabal-rpm> if you need this.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc README.md

%changelog
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct 20 2020 psimons@suse.com
- Update cabal2spec to version 2.6.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 psimons@suse.com
- Update cabal2spec to version 2.6.2.
  Upstream does not provide a change log file.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jun 10 2020 psimons@suse.com
- Update cabal2spec to version 2.6.1.
  Upstream does not provide a change log file.
* Wed May  6 2020 psimons@suse.com
- Update cabal2spec to version 2.6.
  Upstream does not provide a change log file.
* Tue Jan 28 2020 psimons@suse.com
- Update cabal2spec to version 2.5.
  Upstream does not provide a change log file.
* Sat Jan 11 2020 psimons@suse.com
- Update cabal2spec to version 2.4.1.
  Upstream does not provide a change log file.
* Sun Dec 29 2019 psimons@suse.com
- Update cabal2spec to version 2.4.
  Upstream does not provide a change log file.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Jan 17 2019 psimons@suse.com
- Update cabal2spec to version 2.2.2.1.
  Upstream does not provide a change log file.
* Thu Oct  4 2018 psimons@suse.com
- Update cabal2spec to version 2.2.2.
  Upstream does not provide a change log file.
* Fri Jul 20 2018 psimons@suse.com
- Add cabal2spec at version 2.2.1.
